@@ -5,15 +5,18 @@ __license__ = "Apache-2.0"
 def pod(args):
     """Start a Pod"""
     from jina.peapods import Pod
-    with Pod(args) as p:
-        p.join()
+    try:
+        with Pod(args) as p:
+            p.join()
+    except KeyboardInterrupt:
+        pass
 
 
 def pea(args):
     """Start a Pea"""
-    from jina.peapods import Pea
+    from jina.peapods import Runtime
     try:
-        with Pea(args) as p:
+        with Runtime(args) as p:
             p.join()
     except KeyboardInterrupt:
         pass
@@ -57,9 +60,9 @@ def export_api(args):
     if args.yaml_path:
         for yp in args.yaml_path:
             f_name = (yp % __version__) if '%s' in yp else yp
-            from jina.helper import yaml
+            from jina.jaml import JAML
             with open(f_name, 'w', encoding='utf8') as fp:
-                yaml.dump(api_to_dict(), fp)
+                JAML.dump(api_to_dict(), fp)
             default_logger.info(f'API is exported to {f_name}')
 
     if args.json_path:
