@@ -35,26 +35,27 @@ ac_table = {
     'commands': ['--help', '--version', '--version-full', 'hello-world', 'pod', 'flow', 'gateway', 'ping', 'check',
                  'hub', 'pea', 'log', 'client', 'export-api'], 'completions': {
         'hello-world': ['--help', '--workdir', '--logserver', '--logserver-config', '--download-proxy', '--shards',
-                        '--parallel', '--uses-index', '--index-data-url', '--index-batch-size', '--uses-query',
-                        '--query-data-url', '--query-batch-size', '--num-query', '--top-k'],
-        'pod': ['--help', '--name', '--identity', '--uses', '--py-modules', '--uses-internal', '--entrypoint',
+                        '--parallel', '--uses-index', '--index-data-url', '--index-labels-url', '--index-batch-size',
+                        '--uses-query', '--query-data-url', '--query-labels-url', '--query-batch-size', '--num-query',
+                        '--top-k'],
+        'pod': ['--help', '--name', '--identity', '--uses', '--py-modules', '--env', '--uses-internal', '--entrypoint',
                 '--pull-latest', '--volumes', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in',
                 '--socket-out', '--port-ctrl', '--ctrl-with-ipc', '--timeout', '--timeout-ctrl', '--timeout-ready',
-                '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--pea-id', '--num-part',
+                '--expose-public', '--dump-interval', '--read-only', '--separated-workspace', '--pea-id', '--num-part',
                 '--role', '--skip-on-error', '--memory-hwm', '--runtime', '--max-idle-time', '--daemon', '--log-config',
                 '--log-remote', '--log-id', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--host',
                 '--port-expose', '--port-grpc', '--max-message-size', '--proxy', '--remote-access', '--parallel',
                 '--shards', '--polling', '--scheduling', '--uses-before', '--uses-after', '--shutdown-idle'],
         'flow': ['--help', '--uses', '--logserver', '--logserver-config', '--log-id', '--optimize-level',
                  '--output-type', '--output-path', '--inspect'],
-        'gateway': ['--help', '--name', '--identity', '--uses', '--py-modules', '--uses-internal', '--entrypoint',
-                    '--pull-latest', '--volumes', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in',
-                    '--socket-out', '--port-ctrl', '--ctrl-with-ipc', '--timeout', '--timeout-ctrl', '--timeout-ready',
-                    '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--pea-id',
-                    '--num-part', '--role', '--skip-on-error', '--memory-hwm', '--runtime', '--max-idle-time',
-                    '--daemon', '--log-config', '--log-remote', '--log-id', '--ssh-server', '--ssh-keyfile',
-                    '--ssh-password', '--host', '--port-expose', '--port-grpc', '--max-message-size', '--proxy',
-                    '--remote-access', '--prefetch', '--prefetch-on-recv', '--rest-api', '--check-version',
+        'gateway': ['--help', '--name', '--identity', '--uses', '--py-modules', '--env', '--uses-internal',
+                    '--entrypoint', '--pull-latest', '--volumes', '--port-in', '--port-out', '--host-in', '--host-out',
+                    '--socket-in', '--socket-out', '--port-ctrl', '--ctrl-with-ipc', '--timeout', '--timeout-ctrl',
+                    '--timeout-ready', '--expose-public', '--dump-interval', '--read-only', '--separated-workspace',
+                    '--pea-id', '--num-part', '--role', '--skip-on-error', '--memory-hwm', '--runtime',
+                    '--max-idle-time', '--daemon', '--log-config', '--log-remote', '--log-id', '--ssh-server',
+                    '--ssh-keyfile', '--ssh-password', '--host', '--port-expose', '--port-grpc', '--max-message-size',
+                    '--proxy', '--remote-access', '--prefetch', '--prefetch-on-recv', '--rest-api', '--check-version',
                     '--compress', '--compress-hwm', '--compress-lwm'],
         'ping': ['--help', '--timeout', '--retries', '--print-response'],
         'check': ['--help', '--summary-exec', '--summary-driver'], 'hub login': ['--help'],
@@ -63,14 +64,15 @@ ac_table = {
         'hub create': ['--help', '--output-dir', '--template', '--type', '--overwrite'],
         'hub build': ['--help', '--username', '--password', '--registry', '--repository', '--pull', '--push',
                       '--dry-run', '--prune-images', '--raise-error', '--test-uses', '--test-level', '--host-info',
-                      '--daemon'], 'hub push': ['--help', '--username', '--password', '--registry', '--repository'],
+                      '--daemon', '--no-overwrite'],
+        'hub push': ['--help', '--username', '--password', '--registry', '--repository'],
         'hub pull': ['--help', '--username', '--password', '--registry', '--repository'],
         'hub list': ['--help', '--name', '--kind', '--keywords', '--type', '--local-only'],
         'hub': ['--help', 'login', 'new', 'init', 'create', 'build', 'push', 'pull', 'list'],
-        'pea': ['--help', '--name', '--identity', '--uses', '--py-modules', '--uses-internal', '--entrypoint',
+        'pea': ['--help', '--name', '--identity', '--uses', '--py-modules', '--env', '--uses-internal', '--entrypoint',
                 '--pull-latest', '--volumes', '--port-in', '--port-out', '--host-in', '--host-out', '--socket-in',
                 '--socket-out', '--port-ctrl', '--ctrl-with-ipc', '--timeout', '--timeout-ctrl', '--timeout-ready',
-                '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--pea-id', '--num-part',
+                '--expose-public', '--dump-interval', '--read-only', '--separated-workspace', '--pea-id', '--num-part',
                 '--role', '--skip-on-error', '--memory-hwm', '--runtime', '--max-idle-time', '--daemon', '--log-config',
                 '--log-remote', '--log-id', '--ssh-server', '--ssh-keyfile', '--ssh-password', '--host',
                 '--port-expose', '--port-grpc', '--max-message-size', '--proxy', '--remote-access'],
