@@ -73,7 +73,7 @@ def extract_field(resp, callback_on: 'CallbackOnType'):
                          f'must be one of {list(CallbackOnType)}')
 
 
-def safe_callback(func: Callable, continue_on_error: bool, logger) -> Callable:
+def _safe_callback(func: Callable, continue_on_error: bool, logger) -> Callable:
     @wraps(func)
     def arg_wrapper(*args, **kwargs):
         try:
@@ -90,11 +90,8 @@ def safe_callback(func: Callable, continue_on_error: bool, logger) -> Callable:
 
 def callback_exec(response, on_done, on_error, on_always, continue_on_error, logger):
     if on_error and response.status.code >= jina_pb2.StatusProto.ERROR:
-        safe_on_error = safe_callback(on_error, continue_on_error, logger)
-        safe_on_error(response)
+        _safe_callback(on_error, continue_on_error, logger)(response)
     elif on_done:
-        safe_on_done = safe_callback(on_done, continue_on_error, logger)
-        safe_on_done(response)
+        _safe_callback(on_done, continue_on_error, logger)(response)
     if on_always:
-        safe_on_always = safe_callback(on_always, continue_on_error, logger)
-        safe_on_always(response)
+        _safe_callback(on_always, continue_on_error, logger)(response)
