@@ -9,8 +9,9 @@ from threading import Thread
 from typing import Optional, Dict, List, Union
 
 from .helper import _set_peas_args, _set_after_to_pass, _copy_to_head_args, _copy_to_tail_args, _fill_in_host
-from .. import Pea
-from ..peas.headtail import TailPea, HeadPea
+from .. import Runtime
+from ..peas import BasePea
+from ..peas.headtail import HeadPea, TailPea
 from ...enums import *
 
 
@@ -25,7 +26,7 @@ class BasePod(ExitStack):
         :param args: arguments parsed from the CLI
         """
         super().__init__()
-        self.peas = []
+        self.runtimes = []
         self.is_head_router = False
         self.is_tail_router = False
         self.deducted_head = None
@@ -42,7 +43,7 @@ class BasePod(ExitStack):
     def is_idle(self) -> bool:
         """A Pod is idle when all its peas are idle, see also :attr:`jina.peapods.pea.Pea.is_idle`.
         """
-        return all(p.is_idle for p in self.peas if p.is_ready_event.is_set())
+        return all(runtime.is_idle for runtime in self.runtimes if runtime.is_ready_event.is_set())
 
     def close_if_idle(self):
         """Check every second if the pod is in idle, if yes, then close the pod"""
@@ -182,7 +183,7 @@ class BasePod(ExitStack):
     @property
     def num_peas(self) -> int:
         """Get the number of running :class:`BasePea`"""
-        return len(self.peas)
+        return len(self.runtimes)
 
     def __eq__(self, other: 'BasePod'):
         return self.num_peas == other.num_peas and self.name == other.name
@@ -217,13 +218,13 @@ class BasePod(ExitStack):
         """
         # start head and tail
         if self.peas_args['head']:
-            p = HeadPea(self.peas_args['head'])
-            self.peas.append(p)
+            p = Runtime(self.peas_args['head'], pea_cls=HeadPea, allow_remote=False)
+            self.runtimes.append(p)
             self.enter_context(p)
 
         if self.peas_args['tail']:
-            p = TailPea(self.peas_args['tail'])
-            self.peas.append(p)
+            p = Runtime(self.peas_args['tail'], pea_cls=TailPea, allow_remote=False)
+            self.runtimes.append(p)
             self.enter_context(p)
 
         # start real peas and accumulate the storage id
@@ -236,8 +237,8 @@ class BasePod(ExitStack):
         for idx, _args in enumerate(self.peas_args['peas'], start=start_rep_id):
             _args.pea_id = idx
             _args.role = role
-            p = Pea(_args, allow_remote=False)
-            self.peas.append(p)
+            p = Runtime(_args, pea_cls=BasePea, allow_remote=False)
+            self.runtimes.append(p)
             self.enter_context(p)
 
         self.start_sentinels()
@@ -245,7 +246,7 @@ class BasePod(ExitStack):
 
     @property
     def is_shutdown(self) -> bool:
-        return all(not p.is_ready_event.is_set() for p in self.peas)
+        return all(not runtime.is_ready_event.is_set() for runtime in self.runtimes)
 
     def __enter__(self) -> 'BasePod':
         return self.start()
@@ -253,15 +254,15 @@ class BasePod(ExitStack):
     @property
     def status(self) -> List:
         """The status of a BasePod is the list of status of all its Peas """
-        return [p.status for p in self.peas]
+        return [runtime.status for runtime in self.runtimes]
 
     def is_ready(self) -> bool:
         """Wait till the ready signal of this BasePod.
 
         The pod is ready only when all the contained Peas returns is_ready_event
         """
-        for p in self.peas:
-            p.is_ready_event.wait()
+        for runtime in self.runtimes:
+            runtime.is_ready_event.wait()
         return True
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
@@ -270,9 +271,9 @@ class BasePod(ExitStack):
     def join(self):
         """Wait until all peas exit"""
         try:
-            for s in self.peas:
-                s.join()
+            for runtime in self.runtimes:
+                runtime.join()
         except KeyboardInterrupt:
             pass
         finally:
-            self.peas.clear()
+            self.runtimes.clear()
